***************************************************************************************
* Program: 2_Data_Construction.do
* Author: Alexis Rivera-Ballesteros
* Created: 27 Nov 2023
* Modified: 		
* Purpose: Clean, combines, and assembles datasets for analysis
***************************************************************************************

	clear
	set more off
 
	*** WB WDI indicators from WB API https://data.worldbank.org/
	*** WB WDI indicators are udpated regularly. To produce exactly the same figures
	*** we use the WB WDI database version accessed on December 20th, 2023
	*** Lines 17-32 show how to fetch the WDI indicators from WB API
	/*
	wbopendata, indicator(NY.GDP.MKTP.KD; NY.GDP.PCAP.KD; NY.GDP.MKTP.PP.KD; SP.POP.TOTL; NY.GDP.TOTL.RT.ZS; SP.POP.GROW; SI.POV.DDAY; NY.GNP.MKTP.KD; NE.GDI.FTOT.KD) clear long
	drop adminregion adminregionname lendingtype lendingtypename

	drop if region == "NA"

	rename ny_gdp_mktp_pp_kd gdp_pp
	rename ny_gdp_pcap_kd  gdp_kd_pc
	rename ny_gdp_mktp_kd gdp_kd
	rename sp_pop_totl pop
	rename ny_gdp_totl_rt_zs nr_rents_gdp
	rename sp_pop_grow pop_gr
	rename si_pov_dday pov
	rename ny_gnp_mktp_kd gni
	rename ne_gdi_ftot_kd gfcf

	save "${clean}wdi.dta", replace
	*/


	***** WB commodity prices from https://www.worldbank.org/en/research/commodity-markets
	import excel using "${base}CMO-Historical-Data-Monthly.xlsx", clear sheet("Monthly Prices") cellrange(A6) firstrow
	keep A bbl mmbtu I troyoz
	gen year = substr(A, 1, 4)
	gen month = substr(A, 6, 2)
	destring year, replace
	destring month, replace

	gen gas_avg = (mmbtu + I) / 2

	rename bbl oil_avg
	rename troyoz gold_avg

	save "${clean}commodity_prices.dta", replace




	**** Poverty and inequality platform data (2021 version) with poverty line at 1.90 US$ from https://pip.worldbank.org/home
	import delimited using "${base}pip.csv", varnames(1) clear
	
	rename reporting_year year
	rename country_name countryname
	rename country_code countrycode
	
	drop if reporting_level == "rural" & countrycode == "CHN" |  reporting_level == "rural" & countrycode == "IDN" |  reporting_level == "rural" & countrycode == "IND"
	drop if reporting_level == "urban" & countrycode == "CHN" |  reporting_level == "urban" & countrycode == "IDN" |  reporting_level == "urban" & countrycode == "IND"
	
	collapse (mean) mean, by(countryname countrycode year)

		
	replace mean = mean*(365/12)
	
	gsort countrycode year
	
	
	reshape wide mean, i(countryname countrycode) j(year)
	
	drop mean1981 - mean1994

	
	tostring mean1995-mean2019, replace force	
	
	reshape long mean, i(countryname countrycode) j(year)
	
	destring mean, replace
	
	save "${clean}pip.dta", replace
	
	
	
	***** Poverty headcount ratio at $1.90 a day (2011 USD) from WDI database 2021 update
	
	import delimited using "${base}si.pov.dday.csv", clear
	
	keep countryname countrycode time value
	rename time year
	rename value pov190
	
	save "${clean}pov190", replace
	



	**** Changing wealth of nations 2021 data from https://datacatalog.worldbank.org/search/dataset/0042066
	import excel using "${base}CWON2021 Country Tool - Full Dataset.xlsx", clear sheet(country) cellrange(A2) firstrow
 
	drop unit id

	foreach var of varlist totwealth-pop{
		replace `var' = "." if 	`var' == ".."
		destring `var', replace
	}
	
	drop AI-AL

	rename wb_code countrycode
	
	save "${clean}cwon2021.dta", replace
	
	
	
	
	
	
