********************************************************************************
* Program: 3_Tables_Figures
* Author: Alexis Rivera-Ballesteros
* Created: 27 Nov 2023
* Modified: 		
* Purpose: Replicate Main Tables and Figures
********************************************************************************



// FIGURE 1

	use "${clean}wdi.dta", clear
	replace gdp_kd_pc =  gdp_kd_pc / 1000

	* generate line chart
	tw line gdp_kd_pc year if countrycode == "BWA", lcol("185 178 181") lw(0.8) || ///
		line gdp_kd_pc year if countrycode == "IDN", lcol("231 200 185") lw(0.8) || ///
		line gdp_kd_pc year if countrycode == "ZWE", lcol("159 67 97") lw(0.8) || ///
		line gdp_kd_pc year if countrycode == "COD", lcol("30 59 102") lw(0.8) || ///
		scatter gdp_kd_pc year if countrycode == "BWA" & year == 2022, mlab(countryname) mcol("185 178 181") mlabcol("185 178 181") || ///
		scatter gdp_kd_pc year if countrycode == "IDN" & year == 2022, mlab(countryname) mcol("231 200 185") mlabcol("231 200 185") || ///
		scatter gdp_kd_pc year if countrycode == "ZWE" & year == 2022, mlab(countryname) mcol("159 67 97") mlabcol("159 67 97") || ///
		scatter gdp_kd_pc year if countrycode == "COD" & year == 2022, mlab(countryname) mcol("30 59 102") mlabcol("30 59 102") ///
		ytitle("GDP per capita, thousands (constant 2015 US$)", size(small)) xtitle("") legend(off) ///
		xlab(1960(20)2020) xsc(range(1960 2035)) graphregion(color(white))
		
		graph export "${output}figure1.pdf", replace
		graph export "${output}figure1.png", replace


// FIGURE 2 PANEL A

	use "${clean}wdi.dta", clear
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* create groups
	gen group = 1
	replace group = 2 if bb == 1
	replace group = 3 if oecd == 1
	
	gen gdp_pp_pc = gdp_pp / pop
	
	* compute world population and gdp
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year
	
	gen world_pop_weight = (pop/world_pop)
			
	gen w_world_gdp_pc = gdp_pp_pc*(world_pop_weight)
	
	collapse (sum) world_pop_weight w_world_gdp_pc, by(year group)
	
	gen avg_w_world_gdp_pc = w_world_gdp_pc/world_pop_weight

	keep if year >= 1990

	* generate line chart
	tw line avg_w_world_gdp_pc year if group == 2, lcol("159 67 97") lw(0.8) || ///
		line avg_w_world_gdp_pc year if group == 1, lcol("30 59 102") lw(0.8) || ///
		line avg_w_world_gdp_pc year if group == 3, lcol("185 178 181") lw(0.8) ///
		xtitle("") ytitle("Average population weighted GDP per capita" "(constant 2017 international US$, PPP)") ///
		legend(cols(3) order(1 "Bottom Billion" 2 "Emerging Markets" 3 "OECD") pos(6)) ytitle(,size(small)) ///
		xlab(1990(5)2020) graphregion(color(white)) ylab(,angle(0) labsize(small) format(%12.0fc))
		
		graph export "${output}figure2a.pdf", replace
		graph export "${output}figure2a.png", replace
	
	
	
// FIGURE 2 PANEL B

	* compute indexed values to 1990
	gen avg_w_world_gdp_pc_b = avg_w_world_gdp_pc if year == 1990
	bys group (avg_w_world_gdp_pc_b) : replace avg_w_world_gdp_pc_b = avg_w_world_gdp_pc_b[_n-1] if mi(avg_w_world_gdp_pc_b)
	
	gen gdp_pc_i = (avg_w_world_gdp_pc / avg_w_world_gdp_pc_b) * 100
	
	gsort group year

	* generate line chart
	tw line gdp_pc_i year if group == 2, lcol("159 67 97") lw(0.8) || ///
		line gdp_pc_i year if group == 1, lcol("30 59 102") lw(0.8) || ///
		line gdp_pc_i year if group == 3, lcol("185 178 181") lw(0.8) ///
		xtitle("") ytitle("Average population weighted GDP per capita" "Index 1990=100") ///
		legend(cols(3) order(1 "Bottom Billion" 2 "Emerging Markets" 3 "OECD") pos(6)) ytitle(,size(small)) ///
		xlab(1990(5)2020) graphregion(color(white)) ylab(,angle(0) labsize(small) format(%12.0fc))
		
		graph export "${output}figure2b.pdf", replace
		graph export "${output}figure2b.png", replace
	
	
// FIGURE 3 - 9, A2

	use "${clean}wdi.dta", clear

	
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)
	
	* create groups
	gen group = 1
	replace group = 2 if bb == 1
	replace group = 3 if oecd == 1

	gen period1 = year >= 1960 & year <= 2014
	gen period2 = year >= 1960 & year <= 2019
	gen period60s = year >= 1960 & year <= 1969
	gen period70s = year >= 1970 & year <= 1979
	gen period80s = year >= 1980 & year <= 1989
	gen period90s = year >= 1990 & year <= 1999
	gen period00s = year >= 2000 & year <= 2009
	gen period10s = year >= 2010 & year <= 2019
	gen period_on = year >= 1993 & year <= 2003
	gen period_gd = year >= 2004 & year <= 2014
	gen period_nn = year >= 2015 & year <= 2019
		
	encode countrycode, gen(ccode)
	
	* estimate gdp pc growth
	xtset ccode year
	gen gdp_pc_gr = ((gdp_kd_pc-L1.gdp_kd_pc)/L1.gdp_kd_pc)*100
	
	bysort countrycode : egen nr_rents_max = max(nr_rents_gdp)
	gsort countrycode year
	
	bysort countrycode : egen pop_min = min(pop)
	gsort countrycode year

	* restrict sample to countries with resource rents below 75 percent and population greater than 200K
	drop if nr_rents_max >=75
	drop if pop_min < 200000
	
	* drop outliers and volatile data
	drop if countrycode == "LBN" & year <= 1989
	drop if countrycode == "BIH" & year <= 1999
	drop if gdp_pc_gr >= 50
	

	* generate scatterplots by period
	foreach var of varlist period60s period70s period80s period90s period00s period10s period_on period_gd period_nn period1 period2{

	preserve
	
	keep if `var' == 1

	collapse (mean) gdp_kd_pc gdp_pc_gr (first) bb oecd, by(countrycode)
	
	gen log_gdp_pc = log(gdp_kd_pc)
	
	gen group = 0
	replace group = bb == 1
	replace group = 2 if oecd == 1
	
	reg gdp_pc_gr log_gdp_pc
	
	local eq "`e(depvar)' ="
	local eq "`eq' `: display %7.0g _b[_cons]'"
	local eq "`eq' `=cond(_b[log_gdp_pc] > 0, "+", "-")'"
	local eq "`eq' `: display %5.0g abs(_b[log_gdp_pc])' log_gdp_pc"
	
	tw scatter gdp_pc_gr log_gdp_pc if bb == 0 & oecd == 0, mlab(countrycode) mlabcolor(navy) mlabpos(0) mlabsize(vsmall) msym(none) || ///
		scatter gdp_pc_gr log_gdp_pc if bb == 1, mlabcolor(red) mlab(countrycode) mlabpos(0) mlabsize(vsmall)  msym(none) || ///
		scatter gdp_pc_gr log_gdp_pc if oecd == 1, mlabcolor(green)  mlab(countrycode) mlabpos(0) mlabsize(vsmall)  msym(none) || ///
		lfit gdp_pc_gr log_gdp_pc, ///
		ytitle("Average GDP per capita annual growth (%)") xtitle("Log GDP per capita (constant 2015 US$)") ///
		ylab(-10(5)10) xlab(6(1)12) legend(cols(2) order(4 "`eq'") pos(6)) graphregion(c(white)) ///
		note("Note: countries in red = BB; countries in blue = EM; countries in green = OECD", size(small))
		
	graph export "${output}figure3_9_A2_`var'.pdf", replace
	graph export "${output}figure3_9_A2_`var'.png", replace
	
	restore
	
	}
	




// FIGURE 10

	use "${clean}commodity_prices.dta", clear

	* compute indexed values
	gen oil_1960 = oil_avg if year == 1960 & month == 1
	gen gas_1960 = gas_avg if year == 1960 & month == 1
	gen gold_1960 = gold_avg if year == 1960 & month == 1

	replace oil_1960 = oil_1960[_n-1] if mi(oil_1960)
	replace gas_1960 = gas_1960[_n-1] if mi(gas_1960)
	replace gold_1960 = gold_1960[_n-1] if mi(gold_1960)

	gen oil_i = oil_avg / oil_1960
	gen gas_i = gas_avg / gas_1960
	gen gold_i = gold_avg / gold_1960

	gen day = 1

	gen edate = mdy(month, day, year)
	
	* generate line chart
	tw line oil_i gas_i gold_i edate if year <=2021, lcol("30 59 102" "185 178 181" "159 67 97") ///
		xtitle("") ytitle("Indexed price per commodity unit" "(Jan 1960=100)")	 ///
		xlab(1960(36)2022) graphregion(color(white)) xlab(0 "1960" 3653 "1970" 7305 "1980" 10958 "1990" 14610 "2000" 18263 "2010" 21915 "2020") ///
		legend(cols(3) order(1 "Oil" 2 "Natural gas" 3 "Gold") pos(6))

	graph export "${output}figure10.pdf", replace
	graph export "${output}figure10.png", replace




// FIGURE 11 PANEL A

	use "${clean}wdi.dta", clear
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* create groups
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	gen gdp_pp_pc = gdp_pp / pop
	
	* compute popoulation weighted averages
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year

	gen world_pop_weight = (pop/world_pop)
			
	gen w_world_gdp_pc = gdp_pp_pc*(world_pop_weight)
	
	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	collapse (sum) world_pop_weight w_world_gdp_pc, by(period group)
	
	gen avg_w_world_gdp_pc = w_world_gdp_pc/world_pop_weight
	
	replace avg_w_world_gdp_pc = avg_w_world_gdp_pc/1e3
	
	* generate bar chart
	graph bar avg_w_world_gdp_pc, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("GDP per capita, thousands (PPP, international 2017 $)")

	graph export "${output}figure11a.pdf", replace
	graph export "${output}figure11a.png", replace

	
	
// FIGURE 11 PANEL B

	use "${clean}wdi.dta", clear
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* create groups
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	gen gdp_pp_pc = gdp_pp / pop

	encode countrycode, gen(ccode)
	
	* compute GDP per capita growth rates
	xtset ccode year
	gen gdp_pc_gr = ((gdp_pp_pc-L1.gdp_pp_pc)/L1.gdp_pp_pc)*100
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year

	* compute population weighted averages
	gen world_pop_weight = (pop/world_pop)
			
	gen w_world_gdp_pc = gdp_pc_gr*(world_pop_weight)
	
	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	collapse (sum) world_pop_weight w_world_gdp_pc, by(period group)
	
	gen avg_w_world_gdp_pc = w_world_gdp_pc/world_pop_weight
	
	save "${clean}gdppc_gr", replace
	
	* create bar chart
	graph bar avg_w_world_gdp_pc, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average GDP" "per capita annual growth (%)")

	graph export "${output}figure11b.pdf", replace
	graph export "${output}figure11b.png", replace





// FIGURE 12


	use "${clean}wdi.dta", clear

	merge 1:1 countrycode year using "${clean}pip.dta"
	drop if _merge==2
	drop _merge
	
	encode countrycode, gen(ccode)
	
	xtset ccode year
	
	* define periods
	gen period = 0
	replace period = 1 if year >= 1990 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019
	
	* find the first and last year of available data in each period
	egen datayears_preboom = total(!missing(mean)) if period == 1, by(countrycode period)
	
	egen datayears_boom = total(!missing(mean)) if period == 2, by(countrycode period)
	
	egen datayears_postboom = total(!missing(mean)) if period == 3, by(countrycode period)
	
	gen datayears = datayears_preboom
	replace datayears = datayears_boom if missing(datayears)
	replace datayears = datayears_postboom if missing(datayears)
	
	bysort countrycode period (countrycode year) : gen countnonmissing = sum(!missing(mean)) if !missing(mean)
	gsort countrycode year
	
	tab countrycode if countnonmissing == 4
	
	bysort countrycode period : gen mean_first = mean if countnonmissing == 1
	gsort countrycode year
	
	tab countrycode if mean_first != .
	
	bysort countrycode period : gen mean_first_year = year if countnonmissing == 1
	gsort countrycode year

	tab countryname if mean_first_year == 2000
	
	
	xtset ccode year
		
	egen mean_last_year = max(year / (!missing(mean))) , by(countryname period)
	gen what_last_nonmissing  = mean if year == mean_last_year
	bysort countrycode period : egen mean_last = max(what_last_nonmissing)
	gsort countrycode year
	
	
	gen year_diff = mean_last_year - mean_first_year
	
	
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	bysort countrycode : egen year_diff_avg = mean(year_diff)
	gsort countrycode year
	
	tab countryname if year_diff_avg == 0
	
	
	drop if year_diff == 0
	
	* compute compound growth rates
	gen mean_cagr = (((mean_last/mean_first)^(1/year_diff))-1)*100
	
	
	xtset ccode year
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode period year
 
	* compute population growth averages
	gen world_pop_weight = (pop/world_pop) 
	
	drop if mean == .
	keep if countnonmissing == 1
	
	gen w_mean_cagr = mean_cagr*world_pop_weight
	
	collapse (sum) w_mean_cagr world_pop_weight, by(group period)
	
	gen avg_w_group_inc_pc_gr = w_mean_cagr/world_pop_weight
	
	save "${clean}incomepc_gr", replace
	
	* generate bar chart
	graph bar avg_w_group_inc_pc_gr, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Average population-weighted" "income per capita annual growth (%)")
	
	graph export "${output}figure12.pdf", replace
	graph export "${output}figure12.png", replace



// FIGURE 13 PANEL A

	use "${clean}povhc_byregion.dta", clear
	
	rename poor192 povhc19

	
	reshape wide povhc19, i(year) j(region) string
	
	replace povhc19NAC = 0 if mi(povhc19NAC)
	
	* compute values for stacked area chart
	gen sum2 = povhc19EAS + povhc19ECS
	gen sum3 = povhc19EAS + povhc19ECS + povhc19LCN
	gen sum4 = povhc19EAS + povhc19ECS + povhc19LCN + povhc19MEA
	gen sum5 = povhc19EAS + povhc19ECS + povhc19LCN + povhc19MEA + povhc19NAC
	gen sum6 = povhc19EAS + povhc19ECS + povhc19LCN + povhc19MEA + povhc19NAC + povhc19SAS
	gen sum7 = povhc19EAS + povhc19ECS + povhc19LCN + povhc19MEA + povhc19NAC + povhc19SAS + povhc19SSF
	
	* generate stacked area chart
	twoway area povhc19EAS year, color("78 173 234") lw(none) || ///
	rarea povhc19EAS sum2 year, color(orange) lw(none) || ///
	rarea sum2 sum3 year, color("185 178 181") lw(none) || ///
	rarea sum3 sum4 year, color("30 59 102") lw(none) || ///
	rarea sum4 sum5 year, color(green) lw(none) || ///
	rarea sum5 sum6 year, color("232 200 185") lw(none) || ///
	rarea sum6 sum7 year, color("159 67 97") lw(none) ///
	legend(order(1 "EAP" 2 "ECA" 3 "LAC" 4 "MENA" 5 "NAC" 6 "SAS" 7 "SSA") col(4) size(vsmall) pos(6)) xtitle("") ///
	xla(1990(5)2040) ytitle("Million poor")	///
	yscale(range(0, .1 )) ylabel(0(500)2000, angle(0)) plotregion(margin(0)) ///
	graphregion(color(white)) 
	
	graph export "${output}figure13a.pdf", replace
	graph export "${output}figure13a.png", replace
	



// FIGURE 13 PANEL B

	use "${clean}povhc_byregion.dta", clear
	
	rename poor192 povhc19
	
	reshape wide povhc19, i(year) j(region) string
	
	replace povhc19NAC = 0 if mi(povhc19NAC)
	
	* compute values for stacked area chart
	gen sum2 = povhc19EAS + povhc19ECS
	gen sum3 = povhc19EAS + povhc19ECS + povhc19LCN
	gen sum4 = povhc19EAS + povhc19ECS + povhc19LCN + povhc19MEA
	gen sum5 = povhc19EAS + povhc19ECS + povhc19LCN + povhc19MEA + povhc19NAC
	gen sum6 = povhc19EAS + povhc19ECS + povhc19LCN + povhc19MEA + povhc19NAC + povhc19SAS
	gen sum7 = povhc19EAS + povhc19ECS + povhc19LCN + povhc19MEA + povhc19NAC + povhc19SAS + povhc19SSF
	
	keep if year >= 2020
	
	* generate stacked area chart
	twoway area povhc19EAS year, color("78 173 234") lw(none) || ///
	rarea povhc19EAS sum2 year, color(orange) lw(none) || ///
	rarea sum2 sum3 year, color("185 178 181") lw(none) || ///
	rarea sum3 sum4 year, color("30 59 102") lw(none) || ///
	rarea sum4 sum5 year, color(green) lw(none) || ///
	rarea sum5 sum6 year, color("232 200 185") lw(none) || ///
	rarea sum6 sum7 year, color("159 67 97") lw(none) || ///
	scatteri 0 2035 700 2035, recast(line) lcol(red) lpattern(dash) ///
	legend(order(1 "EAP" 2 "ECA" 3 "LAC" 4 "MENA" 5 "NAC" 6 "SAS" 7 "SSA") col(4) size(vsmall) pos(6)) xtitle("") ///
	xla(2020(5)2040) ytitle("Million poor")	///
	yscale(range(0, .1 )) ylabel(0(100)800, angle(0)) plotregion(margin(0)) ///
	graphregion(color(white)) text(0 2038 700 2038 "Poverty headcount" "starts to rise", size(vsmall) color(red))
	
	graph export "${output}figure13b.pdf", replace
	graph export "${output}figure13b.png", replace




// FIGURE 14

	use "${clean}f_povhc_bygroup.dta", clear
	
	keep year group poor192
	
	reshape wide poor192, i(year) j(group)
	
	rename poor1921 em
	rename poor1922 bb
	rename poor1923 oecd
	
	order year bb em oecd
	
	* compute values for stacked area chart
	gen sum2 = bb + em
	gen sum3 = bb + em + oecd
	
	* generate stacked area chart
	twoway area bb year if year<=2030, color("159 67 97") lw(none) || ///
	rarea bb sum2 year  if year<=2030, color("30 59 102") lw(none) || ///
	rarea sum2 sum3 year  if year<=2030, color("185 178 181") lw(none) || ///
	area bb year if year >= 2030, color("159 67 97*0.5") lw(none) || ///
	rarea bb sum2 year if year >= 2030, color("30 59 102*0.5") lw(none) || ///
	rarea sum2 sum3 year if year >= 2030, color("185 178 181*0.5") lw(none) || ///
	scatteri 0 2035 700 2035, recast(line) lcol(red) lpattern(dash) ///
	legend(order(3 "OECD" 2 "EM" 1 "BB") pos(3) col(1)) xtitle("") ///
	xla(2020(5)2040) ytitle("Million poor")	///
	yscale(range(0, .1 )) ylabel(0(100)700, angle(0)) plotregion(margin(0)) ///
	graphregion(color(white)) text(0 2038 700 2038 "Poverty headcount" "starts to rise", size(vsmall) color(red)) ///
	text(0 2032 400 2032 "Linear" "interpolation", size(vsmall))
	
	graph export "${output}figure14.pdf", replace
	graph export "${output}figure14.png", replace
	
	
	
	

	
	

// FIGURE 15 PANEL A

	use "${clean}wdi.dta", clear

	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* define groups
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	
	encode countrycode, gen(ccode)
	
	* compute population growth rate
	xtset ccode year
	gen pop_growth = ((pop-L1.pop)/L1.pop)*100
	
	
	keep if year == 2021

	* generate bar chart
	graph bar pop_growth, asyvars over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) blab(total, format(%6.1fc)) ///
		bar(1, col("159 67 97")) bar(2, col("30 59 102")) bar(3, col("185 178 181")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Average annual population growth rate, 2021 (%)")
	
	graph export "${output}figure15a.pdf", replace
	graph export "${output}figure15a.png", replace




// FIGURE 15 PANEL B


	use "${clean}pov190", clear

	gsort countrycode year
	
	by countrycode : mipolate pov190 year, gen(pov_i) epolate
	
	replace pov_i = 0 if pov_i <0
	
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)
	
	
	keep if year ==2019
	
	* define groups
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1	
	
	
	collapse (mean) pov_i, by(group)

	* generate bar chart
	graph bar pov_i, asyvars over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) blab(total, format(%6.1fc)) ///
		bar(1, col("159 67 97")) bar(2, col("30 59 102")) bar(3, col("185 178 181")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Average poverty rate, 2019 (%)")
	
	graph export "${output}figure15b.pdf", replace
	graph export "${output}figure15b.png", replace


// FIGURE 16

	use "${clean}h_povhc_bygroup.dta", clear
		 
	rename povhc poor_hist
	rename povrate rate_hist
	
	* combine historical with forecasted poverty headcount data under pre-COVID and COVID scenarios
	merge 1:1 group year using "${clean}f_povhc_bygroup.dta"
	
	rename poor191 poor_precovid 
	rename poor192 poor_postcovid 
	rename rate191 rate_precovid 
	rename rate192 rate_postcovid
	
	keep if year <= 2021
	
	drop _merge
	
	replace poor_precovid = poor_hist if year == 2019
	replace poor_postcovid = poor_hist if year == 2019
	replace rate_precovid = rate_hist if year == 2019
	replace rate_postcovid = rate_hist if year == 2019
	
	gsort group year
	
	* generate line chart with scenarios for each group
	tw line poor_hist poor_precovid poor_postcovid year if group == 2, ///
	lcol("30 59 102" "185 178 181" "159 67 97") lpat(solid dash dash) ///
	lw(0.8 0.8 0.8) ytitle("Million people") title("BB") xtitle("") ///
	legend(cols(3) order(1 "Historical" 2 "Without COVID-19" 3 "With COVID-19") pos(6)) ///
	graphregion(color(white))
	graph export "${output}figure16a.pdf", replace
	graph export "${output}figure16a.png", replace
	
	tw line poor_hist poor_precovid poor_postcovid year if group == 1, ///
	lcol("30 59 102" "185 178 181" "159 67 97") lpat(solid dash dash) ///
	lw(0.8 0.8 0.8) ytitle("Million people") title("EM") xtitle("") ///
	legend(cols(3) order(1 "Historical" 2 "Without COVID-19" 3 "With COVID-19") pos(6)) ///
	graphregion(color(white))
	graph export "${output}figure16b.pdf", replace
	graph export "${output}figure16b.png", replace

	
	tw line poor_hist poor_precovid poor_postcovid year if group == 3, ///
	lcol("30 59 102" "185 178 181" "159 67 97") lpat(solid dash dash) ///
	lw(0.8 0.8 0.8) ytitle("Million people") title("OECD") xtitle("") ///
	legend(cols(3) order(1 "Historical" 2 "Without COVID-19" 3 "With COVID-19") pos(6)) ///
	graphregion(color(white))
	graph export "${output}figure16c.pdf", replace
	graph export "${output}figure16c.png", replace
	
	tw line rate_hist rate_precovid rate_postcovid year if group == 2, ///
	lcol("30 59 102" "185 178 181" "159 67 97") lpat(solid dash dash) ///
	lw(0.8 0.8 0.8) ytitle("Average poverty rate (%)") title("BB") xtitle("") ///
	legend(cols(3) order(1 "Historical" 2 "Without COVID-19" 3 "With COVID-19") pos(6)) ///
	graphregion(color(white))
	graph export "${output}figure16d.pdf", replace
	graph export "${output}figure16d.png", replace
	
	tw line rate_hist rate_precovid rate_postcovid year if group == 1, ///
	lcol("30 59 102" "185 178 181" "159 67 97") lpat(solid dash dash) ///
	lw(0.8 0.8 0.8) ytitle("Average poverty rate (%)") title("EM") xtitle("") ///
	legend(cols(3) order(1 "Historical" 2 "Without COVID-19" 3 "With COVID-19") pos(6)) ///
	graphregion(color(white))
	graph export "${output}figure16e.pdf", replace
	graph export "${output}figure16e.png", replace

	
	tw line rate_hist rate_precovid rate_postcovid year if group == 3, ///
	lcol("30 59 102" "185 178 181" "159 67 97") lpat(solid dash dash) ///
	lw(0.8 0.8 0.8) ytitle("Average poverty rate (%)") title("OECD") xtitle("") ///
	legend(cols(3) order(1 "Historical" 2 "Without COVID-19" 3 "With COVID-19") pos(6)) ///
	graphregion(color(white))
	graph export "${output}figure16f.pdf", replace
	graph export "${output}figure16f.png", replace

	





// FIGURE 17


	use "${clean}wdi.dta", clear
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* define groups
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	collapse (sum) gdp_pp pop, by(group year)
	
	gen gdp_pc = gdp_pp / pop
	
	keep if group == 1 | group == 3
	
	keep if year >= 1995
	
	keep year group gdp_pc
	
	reshape wide gdp_pc, i(year) j(group)
	
	set obs 200
	replace year = year[_n-1] + 1 if year > 2022
	
	* use assumed constant annual growth rates
	gen bb_gd_gr = 3.7
	gen oecd_gd_gr = 1.4
	
	* compute projected GDP 
	replace gdp_pc1 = gdp_pc1[_n-1] * (1 + (bb_gd_gr/100)) if year > 2022
	replace gdp_pc3 = gdp_pc3[_n-1] * (1 + (oecd_gd_gr/100)) if year > 2022
	
	replace gdp_pc1 = gdp_pc1/1e3
	replace gdp_pc3 = gdp_pc3/1e3
	
	* generate line chart
	tw line gdp_pc1 gdp_pc3 year if year > =2015 & year <= 2080, lcol("159 67 97" "30 59 102") ///
	legend(cols(2) order(1 "Bottom Billion" 2 "OECD") pos(6)) xtitle("") lw(0.8 0.8) ///
	ytitle("GDP per capita (PPP, international 2017 $), thousands") graphregion(color(white))
	
	graph export "${output}figure17.pdf", replace
	graph export "${output}figure17.png", replace

	



// FIGURE 18 PANEL A


	use "${clean}wdi.dta", clear
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* define groups
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	gen gni_pc = gni / pop

	encode countrycode, gen(ccode)
	
	* compute gni per capita growth rate
	xtset ccode year
	gen gni_pc_gr = ((gni_pc-L1.gni_pc)/L1.gni_pc)*100
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year
	
	* compute population weighted averages
	gen world_pop_weight = (pop/world_pop)
	
	gen w_world_gni_pc = gni_pc_gr*(world_pop_weight)
	
	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	collapse (sum) world_pop_weight w_world_gni_pc, by(period group)
	
	gen avg_w_world_gni_pc = w_world_gni_pc/world_pop_weight
		
	* generage bar chart
	graph bar avg_w_world_gni_pc, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average gross national income" "per capita annual growth (%)")

	graph export "${output}figure18a.pdf", replace
	graph export "${output}figure18a.png", replace





// FIGURE 18 PANEL B


	use "${clean}wdi.dta", clear
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	gen gfcf_pc = gfcf / pop

	encode countrycode, gen(ccode)
	
	xtset ccode year
	gen gfcf_pc_gr = ((gfcf_pc-L1.gfcf_pc)/L1.gfcf_pc)*100
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year
	gen world_pop_weight = (pop/world_pop)
			
	gen w_world_gfcf_pc = gfcf_pc_gr*(world_pop_weight)
	
	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	* Excluded high outliers with volatile data	
	drop if countrycode == "BRB" | countrycode == "BWA" | countrycode == "CPV" | countrycode == "FSM" | countrycode == "GAB" | countrycode == "IRQ" | countrycode == "XKX" | ///
	countrycode == "LCA" | countrycode == "PSE" | countrycode == "STP" | countrycode == "SUR" | countrycode == "SYR"	
	
	* compute population weighted average
	collapse (sum) world_pop_weight w_world_gfcf_pc, by(period group)
	
	gen avg_w_world_gfcf_pc = w_world_gfcf_pc/world_pop_weight
		
	* generate bar chart
	graph bar avg_w_world_gfcf_pc, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average gross fixed capital" "formation per capita annual growth (%)")

	graph export "${output}figure18b.pdf", replace
	graph export "${output}figure18b.png", replace




// FIGURE 19

	use "${clean}wdi.dta", clear

	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* define groups and periods
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1

	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	gen gdp_pc = gdp_pp / pop
	
	encode countrycode, gen(ccode)
	
	* compute GDP per capita growth
	xtset ccode year
	gen gdp_pc_gr = ((gdp_pc-L1.gdp_pc)/L1.gdp_pc)*100
	
	collapse (mean) gdp_pc_gr gdp_pc (first) group, by(countryname countrycode period)
	
	* generate line chart for selected countries
	tw line gdp_pc period if countrycode == "LAO", lcolor(maroon) || ///
		line gdp_pc period if countrycode == "UZB", lcolor(red) || ///
		line gdp_pc period if countrycode == "PAK", lpattern(dash) lcolor(navy) || ///
		line gdp_pc period if countrycode == "HND", lpattern(dash) lcolor(blue) ///
		legend(cols(2) order(1 "Laos (BB)" 2 "Uzbekistan (BB)" 3 "Pakistan (EM)" 4 "Honduras (EM)") pos(6)) ///
		xlab(1 "Old Normal" 2 "Golden Decade" 3 "New Normal") xsc(range(0 4)) xtitle("") ///
		ytitle("GDP per capita (2017 PPP$)") graphregion(c(white))
	
	graph export "${output}figure19.pdf", replace
	graph export "${output}figure19.png", replace
	



// FIGURE 20


		use "${base}combined_data.dta", clear
		capture drop _merge
		drop *_pop
		drop if year < 1960
		reshape wide pwt mad wdi, i(ccode country) j(year)

	*** Define start/end
		gen outcome1960 = (log(pwt1999/pwt1960)/(1999 - 1960))*100
		gen initial1960 = log(pwt1960)
		gen outcome2000 = (log(pwt2018/pwt2000)/(2018 - 2000))*100
		gen initial2000 = log(pwt2000)
		gen outcome2019 = (log(pwt2018/pwt2000)/(2018 - 2000))*100
		gen initial2019 = log(pwt2019)

		tokenize 1960 2000 2019
		local i = 1
		forval n = 1/3{
			local j = `i' + 1
			#delimit ;
				tw 	(lfitci outcome``i'' initial``i'', fcolor(gs10))
					(sc outcome``i'' initial``i'', msymbol(none) mlabsize(vsmall) mlabel(ccode) mlabpos(0) mlabc(black)),
					ytitle("Growth: ``i'' to ``j''")
					xtitle("``i'' income")
					legend(off)
					plotregion(style(none) lcolor(black))  
					xlabel(6.2 "$500" 6.9 "$1k" 7.6 "$2k" 8.5 "$5k" 9.9 "$20k", angle(0)) 
					ylabel(-4 "-4%" -2 "-2%" 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%", notick nogrid)
					graphregion(fcol(white) lcol(white)) 
					xsize(2) ysize(4) scale(1.5)
				;
			#delimit cr
			graph export "${output}figure20_``i''_``j''.pdf", replace 
			graph export "${output}figure20_``i''_``j''.png", replace 
			local ++i
		}
	




	*** Load data
		use "${base}combined_data.dta", clear
		capture drop _merge
		drop *_pop
		drop if year < 1960
		reshape wide pwt mad wdi, i(ccode country) j(year)

	*** Define start/end
		gen outcome1960 = (log(pwt2003/pwt1960)/(2003 - 1960))*100
		gen initial1960 = log(pwt1960)
		gen outcome2004 = (log(pwt2014/pwt2004)/(2014 - 2004))*100
		gen initial2004 = log(pwt2004)
		gen outcome2015 = (log(pwt2019/pwt2015)/(2019 - 2015))*100
		gen initial2015 = log(pwt2015)


		tokenize 1960 2004 2015
		local i = 1
		forval n = 1/3{
			local j = `i' + 1
			#delimit ;
				tw 	(lfitci outcome``i'' initial``i'', fcolor(gs10))
					(sc outcome``i'' initial``i'', msymbol(none) mlabsize(vsmall) mlabel(ccode) mlabpos(0) mlabc(black)),
					ytitle("Growth: ``i'' to ``j''")
					xtitle("``i'' income")
					legend(off)
					plotregion(style(none) lcolor(black))  
					xlabel(6.2 "$500" 6.9 "$1k" 7.6 "$2k" 8.5 "$5k" 9.9 "$20k", angle(0)) 
					ylabel(-4 "-4%" -2 "-2%" 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%", notick nogrid)
					graphregion(fcol(white) lcol(white)) 
					xsize(2) ysize(4) scale(1.5)
				;
			#delimit cr
			graph export "${output}figure20_``i''_``j''.pdf", replace 
			graph export "${output}figure20_``i''_``j''.png", replace 
			local ++i
		}

		


// FIGURE 21

	* code obtained from Kremer et al (2021)
	use "${base}pwt100.dta", clear

	gen pop_2019 = pop if year == 2019
	bys countrycode (pop_2019): replace  pop_2019 = pop_2019[_n-1] if missing(pop_2019)
	gsort countrycode year

	keep if pop_2019 >= 0.2

	drop if countrycode == "GIB" || ///
			countrycode == "MAF" || ///
			countrycode == "OMN" || ///
			countrycode == "PRK" || ///
			countrycode == "QAT" || ///
			countrycode == "SAU" || ///
			countrycode == "TKM" || ///
			countrycode == "TLS" || ///
			countrycode == "VGB" || ///
			countrycode == "KWT" || ///
			countrycode == "CPV" || ///
			countrycode == "VEN" || ///
			countrycode == "GNQ"
			
	gen log_gdppc = log(rgdpna/pop)

	keep if year >= 1960

	local decade 1960 1970 1980 1990 2000 2010 2019

	foreach d of local decade{
		gen gdppc_`d' = log_gdppc if year == `d'
		bys countrycode (gdppc_`d') : replace gdppc_`d' = gdppc_`d'[_n-1] if missing(gdppc_`d')
		gsort countrycode year
	}

	gen gdppcgr_1960 = ((gdppc_1970 - gdppc_1960)/10)*100
	gen gdppcgr_1970 = ((gdppc_1980 - gdppc_1970)/10)*100
	gen gdppcgr_1980 = ((gdppc_1990 - gdppc_1980)/10)*100
	gen gdppcgr_1990 = ((gdppc_2000 - gdppc_1990)/10)*100
	gen gdppcgr_2000 = ((gdppc_2010 - gdppc_2000)/10)*100
	gen gdppcgr_2010 = ((gdppc_2019 - gdppc_2010)/10)*100

	keep if year == 2000

	keep countrycode gdppc_* gdppcgr_*

	reshape long gdppc_ gdppcgr_, i(countrycode) j(decade)

	drop if decade == 2019

	tw scatter /// 
		gdppcgr_ gdppc_, msize(tiny) mcolor(midblue) || ///
		lfit gdppcgr_ gdppc_, by(decade, legend(off) graphregion(color(white)) note("")) msize(tiny) lcolor(black)  ///
		ylab(-10(5)10)  ///
		ytitle("Growth rate in GDP per capita") xtitle("log GDP per capita") 
		
	graph export "${output}figure21.pdf", replace
	graph export "${output}figure21.png", replace




// FIGURE 22

	* code derived from figure 21 and Kremer et al (2021)
	use "${base}pwt100.dta", clear

	gen pop_2019 = pop if year == 2019
	bys countrycode (pop_2019): replace  pop_2019 = pop_2019[_n-1] if missing(pop_2019)
	gsort countrycode year

	keep if pop_2019 >= 0.2

	drop if countrycode == "GIB" || ///
			countrycode == "MAF" || ///
			countrycode == "OMN" || ///
			countrycode == "PRK" || ///
			countrycode == "QAT" || ///
			countrycode == "SAU" || ///
			countrycode == "TKM" || ///
			countrycode == "TLS" || ///
			countrycode == "VGB" || ///
			countrycode == "KWT" || ///
			countrycode == "CPV" || ///
			countrycode == "VEN" || ///
			countrycode == "GNQ"
			
	gen log_gdppc = log(rgdpna/pop)

	keep if year >= 1960

	local decade 1995 2004 2015 2019

	foreach d of local decade{
		gen gdppc_`d' = log_gdppc if year == `d'
		bys countrycode (gdppc_`d') : replace gdppc_`d' = gdppc_`d'[_n-1] if missing(gdppc_`d')
		gsort countrycode year
	}

	gen gdppcgr_1995 = ((gdppc_2004 - gdppc_1995)/10)*100
	gen gdppcgr_2004 = ((gdppc_2015 - gdppc_2004)/10)*100
	gen gdppcgr_2015 = ((gdppc_2019 - gdppc_2015)/10)*100


	keep if year == 2000

	keep countrycode gdppc_* gdppcgr_*

	reshape long gdppc_ gdppcgr_, i(countrycode) j(decade)

	drop if decade == 2019

	label def decade 1995 "1995 - 2003" 2004 "2004 - 2014" 2015 "2015 - 2019"

	label val decade decade

	tw scatter /// 
		gdppcgr_ gdppc_, msize(tiny) mcolor(midblue) || ///
		lfit gdppcgr_ gdppc_, by(decade, cols(3) legend(off) graphregion(color(white)) note("")) msize(tiny) lcolor(black)  ///
		ylab(-10(5)10)  ///
		ytitle("Growth rate in GDP per capita") xtitle("log GDP per capita") 
		
	graph export "${output}figure22.pdf", replace
	graph export "${output}figure22.png", replace





// FIGURE 23 PANEL A

	use "${base}lm_wpid_web.dta", clear
	
	rename contcod countrycode
	
	* exclude urban / rural surveys
	drop if countrycode == "CHN-R" | countrycode == "CHN-U" | countrycode == "IND-R" | countrycode == "IND-U" | countrycode == "IDN-R" | countrycode == "IDN-U"
	

	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* count number of nonmissing data
	gsort countrycode year
	
	gen count = 1
		
	collapse (sum) count (first) bb oecd, by(countrycode year)
	
	gen count2 = 1
	
	collapse (sum) count2 (first) bb oecd, by(countrycode)
	
	keep if count2 <= 2
	
	gen count3 = 1
	
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	collapse (sum) count3, by (group)

	* create bar chart
	graph bar count3, over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) ytitle("%") ///
		graphregion(color(white))

	graph export "${output}figure23a.pdf", replace
	graph export "${output}figure23a.png", replace


	
	
// FIGURE 23 PANEL B

	use "${base}lm_wpid_web.dta", clear
	
	rename contcod countrycode
	
	* exclude urban / rural surveys
	drop if countrycode == "CHN-R" | countrycode == "CHN-U" | countrycode == "IND-R" | countrycode == "IND-U" | countrycode == "IDN-R" | countrycode == "IDN-U"
	

	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)


	gsort countrycode year
	
	gen count = 1
		
	collapse (sum) count (first) bb oecd, by(countrycode year)

	
	gen count3 = 1
	
	
	collapse (sum) count3 (first) bb oecd, by (country)
	
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	collapse (mean) count3, by(group)

	* generate bar chart
	graph bar count3, over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) ytitle("Average number of years") ///
		blabel(total, format(%12.1fc)) graphregion(color(white))
	
	graph export "${output}figure23b.pdf", replace
	graph export "${output}figure23b.png", replace

	
	
	
// FIGURE 24 PANEL A

	use "${clean}wdi.dta", clear
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* Define groups
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	gen gdp_pp_pc = gdp_pp / pop

	encode countrycode, gen(ccode)
	
	* compute GDP per capita growth
	xtset ccode year
	gen gdp_pc_gr = ((gdp_pp_pc-L1.gdp_pp_pc)/L1.gdp_pp_pc)*100
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year
	
	* compute population weighted averages
	gen world_pop_weight = (pop/world_pop)
	
	gen w_world_gdp_pc = gdp_pc_gr*(world_pop_weight)
	
	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	collapse (sum) world_pop_weight w_world_gdp_pc, by(period group)
	
	gen avg_w_world_gdp_pc = w_world_gdp_pc/world_pop_weight
	
	* create bar chart
	graph bar avg_w_world_gdp_pc, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average GDP" "per capita annual growth (%)")

	graph export "${output}figure24a.pdf", replace
	graph export "${output}figure24a.png", replace
	
	
	
	


// FIGURE 24 PANEL B

	use "${clean}wdi.dta", clear
	merge 1:1 countrycode year using "${clean}pip.dta"
	keep if _merge==3
	drop _merge
	
	
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)
	
	bys countrycode : egen pip = mean(mean)
	drop if pip == .
	
	* define groups
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	gen gdp_pp_pc = gdp_pp / pop

	encode countrycode, gen(ccode)
	
	* compute GDP per capita growth rate
	xtset ccode year
	gen gdp_pc_gr = ((gdp_pp_pc-L1.gdp_pp_pc)/L1.gdp_pp_pc)*100
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year
	
	* compute population weighted averages
	gen world_pop_weight = (pop/world_pop)
			
	gen w_world_gdp_pc = gdp_pc_gr*(world_pop_weight)
	
	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	collapse (sum) world_pop_weight w_world_gdp_pc, by(period group)
	
	gen avg_w_world_gdp_pc = w_world_gdp_pc/world_pop_weight
	
	* generate bar chart
	graph bar avg_w_world_gdp_pc, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average GDP" "per capita annual growth (%)")

	graph export "${output}figure24b.pdf", replace
	graph export "${output}figure24b.png", replace





// FIGURE A1 PANEL A

	use "${clean}wdi.dta", clear
	
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)
	
	merge m:1 countrycode using "${base}fcv", nogen norep
	replace fcv = 0 if mi(fcv)
	
	gen gdp_pp_pc = gdp_pp / pop

	encode countrycode, gen(ccode)
	
	* compute GDP per capita growth
	xtset ccode year
	gen gdp_pc_gr = ((gdp_pp_pc-L1.gdp_pp_pc)/L1.gdp_pp_pc)*100
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year
	
	* compute population weighted averages
	gen world_pop_weight = (pop/world_pop)
	
	gen w_world_gdp_pc = gdp_pc_gr*(world_pop_weight)
	
	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	gen group = 4 if fcv == 0 & bb == 1
	replace group = 5 if fcv == 1
	
	collapse (sum) world_pop_weight w_world_gdp_pc, by(period group)
	
	gen avg_w_world_gdp_pc = w_world_gdp_pc/world_pop_weight
	
	* append with GDP per capita growth rate previously computed
	append using "${clean}gdppc_gr"
	
	order group period
	
	gsort group period
	
	graph bar avg_w_world_gdp_pc, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD" 4 "Non FCV BB" 5 "FCV")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average GDP" "per capita annual growth (%)")

	graph export "${output}figureA1a.pdf", replace
	graph export "${output}figureA1a.png", replace



	
// FIGURE A1 PANEL B
	
	
	use "${clean}cwon2021.dta", clear

	
	merge m:1 countrycode using "${base}fcv", nogen norep
	replace fcv = 0 if mi(fcv)
	
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	gen group = 4 if fcv == 0 & bb == 1
	replace group = 5 if fcv == 1
	

	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	
	gen tw_pc = totwealth/pop
	gen pk_pc = pk/pop
	gen nk_pc = nk/pop
	gen hc_pc = hc/pop
	
	encode countrycode, gen(ccode)
	
	* Compute wealth growth rates
	xtset ccode year
	gen tw_pc_gr = ((tw_pc-L1.tw_pc)/L1.tw_pc)*100
	gen pk_pc_gr = ((pk_pc-L1.pk_pc)/L1.pk_pc)*100
	gen hc_pc_gr = ((hc_pc-L1.hc_pc)/L1.hc_pc)*100
	gen nk_pc_gr = ((nk_pc-L1.nk_pc)/L1.nk_pc)*100
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year
	
	* compute population weighted averages
	gen world_pop_weight = (pop/world_pop)
	
	gen w_world_tw_pc_gr = tw_pc_gr*(world_pop_weight)
	
	gen w_world_pk_pc_gr = pk_pc_gr*(world_pop_weight)
	
	gen w_world_hc_pc_gr = hc_pc_gr*(world_pop_weight)
	
	gen w_world_nk_pc_gr = nk_pc_gr*(world_pop_weight)
	
	
	collapse (sum) tw_pc_gr world_pop_weight w_world_tw_pc_gr ///
	pk_pc_gr w_world_pk_pc_gr nk_pc_gr w_world_nk_pc_gr ///
	hc_pc_gr w_world_hc_pc_gr, by(period group)
	
	gen avg_w_world_tw_pc_gr = w_world_tw_pc_gr/world_pop_weight
	
	gen avg_w_world_pk_pc_gr = w_world_pk_pc_gr/world_pop_weight
	
	gen avg_w_world_nk_pc_gr = w_world_nk_pc_gr/world_pop_weight
	
	gen avg_w_world_hc_pc_gr = w_world_hc_pc_gr/world_pop_weight
	
	xtset group period
	
	* append with previously estimated growth rates
	append using "${clean}totwealthpc_gr"
	
	order group period
	
	gsort group period	
	
	* generage bar chart
	graph bar avg_w_world_tw_pc_gr, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD" 4 "Non FCV BB" 5 "FCV")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average total wealth" "per capita annual growth (%)")
		
	graph export "${output}figureA1b.pdf", replace
	graph export "${output}figureA1b.png", replace

	
	
	

// FIGURE A1 PANEL C

	use "${clean}wdi.dta", clear

	merge 1:1 countrycode year using "${clean}pip.dta"
	drop if _merge==2
	drop _merge
	
	encode countrycode, gen(ccode)
	
	xtset ccode year
	
	* define periods
	gen period = 0
	replace period = 1 if year >= 1990 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019
	
	* find data and years with non missing data
	egen datayears_preboom = total(!missing(mean)) if period == 1, by(countrycode period)
	
	egen datayears_boom = total(!missing(mean)) if period == 2, by(countrycode period)
	
	egen datayears_postboom = total(!missing(mean)) if period == 3, by(countrycode period)
	
	gen datayears = datayears_preboom
	replace datayears = datayears_boom if missing(datayears)
	replace datayears = datayears_postboom if missing(datayears)
	
	bysort countrycode period (countrycode year) : gen countnonmissing = sum(!missing(mean)) if !missing(mean)
	gsort countrycode year
	
	tab countrycode if countnonmissing == 4
	
	bysort countrycode period : gen mean_first = mean if countnonmissing == 1
	gsort countrycode year
	
	tab countrycode if mean_first != .
	
	bysort countrycode period : gen mean_first_year = year if countnonmissing == 1
	gsort countrycode year

	tab countryname if mean_first_year == 2000

	
	xtset ccode year
		
	egen mean_last_year = max(year / (!missing(mean))) , by(countryname period)
	gen what_last_nonmissing  = mean if year == mean_last_year
	bysort countryname period : egen mean_last = max(what_last_nonmissing)
	gsort countrycode year
	
	gen year_diff = mean_last_year - mean_first_year
	
	tab countryname if year_diff == 0

	
	merge m:1 countrycode using "${base}fcv", nogen norep
	replace fcv = 0 if mi(fcv)
	
	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	xtset ccode year
	by ccode : egen year_diff_avg = mean(year_diff)
	gsort countrycode year
	
	tab countryname if year_diff_avg == 0
	
	
	drop if year_diff == 0
	
	* estimate compound growth rates
	gen mean_cagr = (((mean_last/mean_first)^(1/year_diff))-1)*100
	
	
	xtset ccode year
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year


	gen world_pop_weight = (pop/world_pop) 
	
	drop if mean == .
	keep if countnonmissing == 1
	
	* compute population weighted averages
	gen w_mean_cagr = mean_cagr*world_pop_weight
	
	gen group = 4 if fcv == 0 & bb == 1
	replace group = 5 if fcv == 1
	
	collapse (sum) w_mean_cagr world_pop_weight, by(group period)
	
	gen avg_w_group_inc_pc_gr = w_mean_cagr/world_pop_weight
	
	* append with previously estimated income growth rates
	append using "${clean}incomepc_gr"
	
	order group period
	
	gsort group period	
	
	* generate bar chart
	graph bar avg_w_group_inc_pc_gr, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD" 4 "Non FCV BB" 5 "FCV")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Average population-weighted" "income per capita annual growth (%)")
		
	graph export "${output}figureA1c.pdf", replace
	graph export "${output}figureA1c.png", replace

	


// FIGURE A2

***** Generated together with figures 3-9



// FIGURE A3

	* code derived from Patel et al (2021)
	
	*** 1960-2003
		use "${base}combined_data.dta", clear
		capture drop _merge
		drop *_pop
		drop if year < 1960
		reshape wide pwt mad wdi, i(ccode country) j(year)				
			

		gen gdp_growth = (log(pwt2003/pwt1960)/(2003 - 1960))*100
		gen gdp_1960 = log(pwt1960)
		reg gdp_growth gdp_1960, r
		test _b[gdp_1960]=0

		mat b = e(b)
		local constant : display %4.2f = b[1,2]
		display  `constant'
		local x : display %4.2f = b[1,1]
		local r2 : display %5.4f = e(r2)

		local heads_a     "y="
		local heads_b     "x"

		local p_value : display %5.4f = r(p)
		
		tw lfitci gdp_growth gdp_1960, fcolor(gs10) || ///
			sc gdp_growth gdp_1960, msymbol(none) mlabsize(vsmall) mlabel(ccode) mlabpos(0) mlabc(black) ///
			ytitle("Growth: 1960 to 2003") ///
			xtitle("1960 income") ///
			plotregion(style(none) lcolor(black)) legend(off) ///  
			xlabel(6.2 "$500" 6.9 "$1k" 7.6 "$2k" 8.5 "$5k" 9.9 "$20k", angle(0)) ///
			ylabel(-4 "-4%" -2 "-2%" 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%", notick nogrid) ///
			graphregion(fcol(white) lcol(white)) ///
			xsize(2) ysize(4) scale(1.5) ///
			caption(" " "{superscript:`heads_a' `constant'+}{superscript:`x'`heads_b'+ε, }" "{superscript:R-squred=`r2', } {superscript:P-value: `p_value'}", ///
            justification(center) size(*1.5) position(6))
			
			graph export "${output}figureA3a.pdf", replace
			graph export "${output}figureA3a.png", replace
			
	


	*** 1960-2014
		use "${base}combined_data.dta", clear
		capture drop _merge
		drop *_pop
		drop if year < 1960
		reshape wide pwt mad wdi, i(ccode country) j(year)	

		gen gdp_growth = (log(pwt2014/pwt1960)/(2014 - 1960))*100
		gen gdp_1960 = log(pwt1960)
		reg gdp_growth gdp_1960, r
				
		test _b[gdp_1960]=0

		mat b = e(b)
		local constant : display %4.2f = b[1,2]
		display  `constant'
		local x : display %4.2f = b[1,1]
		local r2 : display %5.4f = e(r2)

		local heads_a     "y="
		local heads_b     "x"

		local p_value : display %5.4f = r(p)
		
		tw lfitci gdp_growth gdp_1960, fcolor(gs10) || ///
			sc gdp_growth gdp_1960, msymbol(none) mlabsize(vsmall) mlabel(ccode) mlabpos(0) mlabc(black) ///
			ytitle("Growth: 1960 to 2014") ///
			xtitle("1960 income") ///
			plotregion(style(none) lcolor(black)) legend(off) ///  
			xlabel(6.2 "$500" 6.9 "$1k" 7.6 "$2k" 8.5 "$5k" 9.9 "$20k", angle(0)) ///
			ylabel(-4 "-4%" -2 "-2%" 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%", notick nogrid) ///
			graphregion(fcol(white) lcol(white)) ///
			xsize(2) ysize(4) scale(1.5) ///
			caption(" " "{superscript:`heads_a' `constant'+}{superscript:`x'`heads_b'+ε, }" "{superscript:R-squred=`r2', } {superscript:P-value: `p_value'}", ///
            justification(center) size(*1.5) position(6))
			
			graph export "${output}figureA3b.pdf", replace
			graph export "${output}figureA3b.png", replace

				   
	*** 1960-2019
		use "${base}combined_data.dta", clear
		capture drop _merge
		drop *_pop
		drop if year < 1960
		reshape wide pwt mad wdi, i(ccode country) j(year)				
			

		gen gdp_growth = (log(pwt2019/pwt1960)/(2019 - 1960))*100
		gen gdp_1960 = log(pwt1960)
		reg gdp_growth gdp_1960, r
		test _b[gdp_1960]=0

		mat b = e(b)
		local constant : display %4.2f = b[1,2]
		display  `constant'
		local x : display %4.2f = b[1,1]
		local r2 : display %5.4f = e(r2)

		local heads_a     "y="
		local heads_b     "x"

		local p_value : display %5.4f = r(p)
		
		tw lfitci gdp_growth gdp_1960, fcolor(gs10) || ///
			sc gdp_growth gdp_1960, msymbol(none) mlabsize(vsmall) mlabel(ccode) mlabpos(0) mlabc(black) ///
			ytitle("Growth: 1960 to 2019") ///
			xtitle("1960 income") ///
			plotregion(style(none) lcolor(black)) legend(off) ///  
			xlabel(6.2 "$500" 6.9 "$1k" 7.6 "$2k" 8.5 "$5k" 9.9 "$20k", angle(0)) ///
			ylabel(-4 "-4%" -2 "-2%" 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%", notick nogrid) ///
			graphregion(fcol(white) lcol(white)) ///
			xsize(2) ysize(4) scale(1.5) ///
			caption(" " "{superscript:`heads_a' `constant'+}{superscript:`x'`heads_b'+ε, }" "{superscript:R-squred=`r2', } {superscript:P-value: `p_value'}", ///
            justification(center) size(*1.5) position(6))
			
			graph export "${output}figureA3c.pdf", replace
			graph export "${output}figureA3c.png", replace
			
			
		



// FIGURE A4


	* code derived from Patel et al (2021)

			
	*** 2003-2008
		use "${base}combined_data.dta", clear
		capture drop _merge
		drop *_pop
		drop if year < 1960
		reshape wide pwt mad wdi, i(ccode country) j(year)			
			

		gen gdp_growth = (log(pwt2008/pwt2003)/(2008 - 2003))*100
		gen gdp_2003 = log(pwt2003)
		reg gdp_growth gdp_2003, r
		test _b[gdp_2003]=0

		mat b = e(b)
		local constant : display %4.2f = b[1,2]
		display  `constant'
		local x : display %4.2f = b[1,1]
		local r2 : display %5.4f = e(r2)

		local heads_a     "y="
		local heads_b     "x"

		local p_value : display %5.4f = r(p)
		
		drop if ccode == "ZWE" // dropping outlier from scatterplot

		
		tw lfitci gdp_growth gdp_2003, fcolor(gs10) || ///
			sc gdp_growth gdp_2003, msymbol(none) mlabsize(vsmall) mlabel(ccode) mlabpos(0) mlabc(black) ///
			ytitle("Growth: 2003 to 2008") ///
			xtitle("2003 income") ///
			plotregion(style(none) lcolor(black)) legend(off) ///  
			xlabel(6.2 "$500" 6.9 "$1k" 7.6 "$2k" 8.5 "$5k" 9.9 "$20k", angle(0)) ///
			ylabel(-6 "-6%" -4 "-4%" -2 "-2%" 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%" 10 "10%" 12 "12%" 14 "14%", notick nogrid) ///
			graphregion(fcol(white) lcol(white)) ///
			xsize(2) ysize(4) scale(1.5) ///
			caption(" " "{superscript:`heads_a' `constant'+}{superscript:`x'`heads_b'+ε, }" "{superscript:R-squred=`r2', } {superscript:P-value: `p_value'}", ///
            justification(center) size(*1.5) position(6))
			
			graph export "${output}figureA4a.pdf", replace
			graph export "${output}figureA4a.png", replace
			
			
			
			
	*** 2009-2014
		use "${base}combined_data.dta", clear
		capture drop _merge
		drop *_pop
		drop if year < 1960
		reshape wide pwt mad wdi, i(ccode country) j(year)	
			

		gen gdp_growth = (log(pwt2014/pwt2009)/(2014 - 2009))*100
		gen gdp_2009 = log(pwt2009)
		reg gdp_growth gdp_2009, r
		test _b[gdp_2009]=0

		mat b = e(b)
		local constant : display %4.2f = b[1,2]
		display  `constant'
		local x : display %4.2f = b[1,1]
		local r2 : display %5.4f = e(r2)

		local heads_a     "y="
		local heads_b     "x"

		local p_value : display %5.4f = r(p)
				
		tw lfitci gdp_growth gdp_2009, fcolor(gs10) || ///
			sc gdp_growth gdp_2009, msymbol(none) mlabsize(vsmall) mlabel(ccode) mlabpos(0) mlabc(black) ///
			ytitle("Growth: 2009 to 2014") ///
			xtitle("2009 income") ///
			plotregion(style(none) lcolor(black)) legend(off) ///  
			xlabel(6.2 "$500" 6.9 "$1k" 7.6 "$2k" 8.5 "$5k" 9.9 "$20k", angle(0)) ///
			ylabel(-6 "-6%" -4 "-4%" -2 "-2%" 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%" 10 "10%" 12 "12%" 14 "14%", notick nogrid) ///
			graphregion(fcol(white) lcol(white)) ///
			xsize(2) ysize(4) scale(1.5) ///
			caption(" " "{superscript:`heads_a' `constant'+}{superscript:`x'`heads_b'+ε, }" "{superscript:R-squred=`r2', } {superscript:P-value: `p_value'}", ///
            justification(center) size(*1.5) position(6))
			
			graph export "${output}figureA4b.pdf", replace
			graph export "${output}figureA4b.png", replace
			
			
			
	*** 2015-2019
		use "${base}combined_data.dta", clear
		capture drop _merge
		drop *_pop
		drop if year < 1960
		reshape wide pwt mad wdi, i(ccode country) j(year)				
			

		gen gdp_growth = (log(pwt2019/pwt2015)/(2019 - 2015))*100
		gen gdp_2015 = log(pwt2015)
		reg gdp_growth gdp_2015, r
		test _b[gdp_2015]=0

		mat b = e(b)
		local constant : display %4.2f = b[1,2]
		display  `constant'
		local x : display %4.2f = b[1,1]
		local r2 : display %5.4f = e(r2)

		local heads_a     "y="
		local heads_b     "x"

		local p_value : display %5.4f = r(p)
		
		tw lfitci gdp_growth gdp_2015, fcolor(gs10) || ///
			sc gdp_growth gdp_2015, msymbol(none) mlabsize(vsmall) mlabel(ccode) mlabpos(0) mlabc(black) ///
			ytitle("Growth: 2015 to 2019") ///
			xtitle("2015 income") ///
			plotregion(style(none) lcolor(black)) legend(off) ///  
			xlabel(6.2 "$500" 6.9 "$1k" 7.6 "$2k" 8.5 "$5k" 9.9 "$20k", angle(0)) ///
			ylabel(-6 "-6%" -4 "-4%" -2 "-2%" 0 "0%" 2 "2%" 4 "4%" 6 "6%" 8 "8%" 10 "10%" 12 "12%" 14 "14%", notick nogrid) ///
			graphregion(fcol(white) lcol(white)) ///
			xsize(2) ysize(4) scale(1.5) ///
			caption(" " "{superscript:`heads_a' `constant'+}{superscript:`x'`heads_b'+ε, }" "{superscript:R-squred=`r2', } {superscript:P-value: `p_value'}", ///
            justification(center) size(*1.5) position(6))
			
			graph export "${output}figureA4c.pdf", replace
			graph export "${output}figureA4c.png", replace
			

			
			
			
			
// TABLE A1

	use "${clean}wdi.dta", clear
	
	keep if year == 2022
	
	keep countryname countrycode regionname incomelevelname pop
	
	egen pop_world = sum(pop)
	
	gen s_pop = (pop / pop_world) * 100
	
	merge 1:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)
	
	merge 1:1 countrycode using "${base}fcv", nogen norep
	replace fcv = 0 if mi(fcv)	
	
	* define groups
	keep if bb == 1
	gen BB = "BB" if bb == 1
	
	gen FCV = "Non FCV"
	replace FCV = "FCV" if fcv == 1
	
	keep countryname regionname incomelevelname pop s_pop BB FCV
	
	replace pop = pop / 1e6
	format pop %12.1gc
	format s_pop %12.1gc
	
	* label columns
	label var countryname "Country name"
	label var regionname "Region name"
	label var incomelevelname "Income level"
	label var pop "Population (millions)"
	label var s_pop "Share in world's pop (%)"
	label var BB "BB?"
	label var FCV "FCV?"
	
	gsort regionname -s_pop

	* export table to Excel
	export excel using "${output}tableA1", firstrow(varlabels) replace
	
	
// TABLE A2

	use "${clean}wdi.dta", clear
	
	keep if year == 2022
	
	keep countryname countrycode regionname incomelevelname pop
	
	egen pop_world = sum(pop)
	
	gen s_pop = (pop / pop_world) * 100
	
	merge 1:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)
	
	merge 1:1 countrycode using "${base}fcv", nogen norep
	replace fcv = 0 if mi(fcv)	
	
	* define groups
	keep if bb == 0 & fcv == 1
	gen BB = "NO"
	
	gen FCV = "FCV" if fcv == 1 
	
	keep countryname regionname incomelevelname pop s_pop BB FCV
	
	replace pop = pop / 1e6
	format pop %12.1gc
	format s_pop %12.1gc
	
	* label columns
	label var countryname "Country name"
	label var regionname "Region name"
	label var incomelevelname "Income level"
	label var pop "Population (millions)"
	label var s_pop "Share in world's pop (%)"
	label var BB "BB?"
	label var FCV "FCV?"
	
	gsort regionname -s_pop

	* export table to Excel
	
	export excel using "${output}tableA2", firstrow(varlabels) replace	
	
		
			
			
			

// FIGURE B1 PANEL A


	use "${clean}cwon2021.dta", clear

	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* define groups and periods
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1

	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	gen tw_pc = totwealth/pop
	
	collapse (mean) tw_pc, by(group period)
	
	replace tw_pc = tw_pc/1e3
	
	* generate bar chart
	graph bar tw_pc, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
	over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
	legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
	ytitle("Wealth per capita, thousands (constant 2018 US$)")

	graph export "${output}figureB1a.pdf", replace
	graph export "${output}figureB1a.png", replace


// FIGURE B1 PANEL B

	use "${clean}cwon2021.dta", clear

	merge m:1 countrycode using "${base}bb_countries", nogen norep
	replace bb = 0 if mi(bb)

	merge m:1 countrycode using "${base}oecd", nogen norep
	replace oecd = 0 if mi(oecd)

	* define groups and periods
	gen group = 2
	replace group = 1 if bb == 1
	replace group = 3 if oecd == 1
	
	

	gen period = 0
	replace period = 1 if year >= 1995 & year <= 2003
	replace period = 2 if year >= 2004 & year <= 2014
	replace period = 3 if year >= 2015 & year <= 2019

	drop if period == 0
	
	
	gen tw_pc = totwealth/pop
	gen pk_pc = pk/pop
	gen nk_pc = nk/pop
	gen hc_pc = hc/pop
	
	encode countrycode, gen(ccode)
	
	* compute wealth and assets growth rates
	xtset ccode year
	gen tw_pc_gr = ((tw_pc-L1.tw_pc)/L1.tw_pc)*100
	gen pk_pc_gr = ((pk_pc-L1.pk_pc)/L1.pk_pc)*100
	gen hc_pc_gr = ((hc_pc-L1.hc_pc)/L1.hc_pc)*100
	gen nk_pc_gr = ((nk_pc-L1.nk_pc)/L1.nk_pc)*100
	
	bysort year : egen world_pop = sum(pop)
	gsort countrycode year
	
	* compute population weighted averages
	gen world_pop_weight = (pop/world_pop)
	
	gen w_world_tw_pc_gr = tw_pc_gr*(world_pop_weight)
	
	gen w_world_pk_pc_gr = pk_pc_gr*(world_pop_weight)
	
	gen w_world_hc_pc_gr = hc_pc_gr*(world_pop_weight)
	
	gen w_world_nk_pc_gr = nk_pc_gr*(world_pop_weight)
	
	
	collapse (sum) tw_pc_gr world_pop_weight w_world_tw_pc_gr ///
	pk_pc_gr w_world_pk_pc_gr nk_pc_gr w_world_nk_pc_gr ///
	hc_pc_gr w_world_hc_pc_gr, by(period group)
	
	gen avg_w_world_tw_pc_gr = w_world_tw_pc_gr/world_pop_weight
	
	gen avg_w_world_pk_pc_gr = w_world_pk_pc_gr/world_pop_weight
	
	gen avg_w_world_nk_pc_gr = w_world_nk_pc_gr/world_pop_weight
	
	gen avg_w_world_hc_pc_gr = w_world_hc_pc_gr/world_pop_weight
	
	xtset group period
	
	save "${clean}totwealthpc_gr", replace

	* create bar charts
	graph bar avg_w_world_tw_pc_gr, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average total wealth" "per capita annual growth (%)")

	graph export "${output}figureB1b.pdf", replace
	graph export "${output}figureB1b.png", replace


// FIGURE B2 PANEL A

	graph bar avg_w_world_pk_pc_gr, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average produced capital" "per capita annual growth (%)")

	graph export "${output}figureB2a.pdf", replace
	graph export "${output}figureB2a.png", replace



// FIGURE B2 PANEL B

	graph bar avg_w_world_hc_pc_gr, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average human capital" "per capita annual growth (%)")

	graph export "${output}figureB2b.pdf", replace
	graph export "${output}figureB2b.png", replace


// FIGURE B2 PANEL C

	graph bar avg_w_world_nk_pc_gr, asyvars over(period, relabel(1 "Old Normal" 2 "Golden Decade" 3 "New Normal")) blabel(total, format(%12.1fc)) ///
		over(group, relabel(1 "BB" 2 "EM" 3 "OECD")) bar(1, col("185 178 181")) bar(2, col("159 67 97")) bar(3, col("30 59 102")) ///
		legend(cols(3) size(small) pos(6)) graphregion(color(white)) ///
		ytitle("Population-weighted average natural capital" "per capita annual growth (%)")

	graph export "${output}figureB2c.pdf", replace
	graph export "${output}figureB2c.png", replace

	
	
**** End of dofile	
	
	
	
	
	
	
